:mod:`kwant.wraparound` -- Wrapping around translational symmetries
===================================================================
.. module:: kwant.wraparound
.. autosummary::
   :toctree: generated/

   wraparound
   plot_2d_bands
